# -*- coding: utf-8 -*-

from django.conf import settings
from django.contrib import admin as django_admin
from django.utils.translation import ugettext_lazy as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from . import admin
from . import models


@plugin_pool.register_plugin
class SectionPlugin(admin.SectionAdminMixin, CMSPluginBase):
    model = models.SectionSettings
    module = _("box")
    name = _("section")
    render_template = "cms/empty.html"
    allow_children = True,
    child_classes = settings.CMS_BOX_SECTION_CHILD_CLASSES

    def render(self, context, instance, placeholder):
        if instance.status == 0:
            return context

        self.render_template = instance.template_name

        context.update({
            'instance': instance,
            'placeholder': placeholder,
        })
        return context


@plugin_pool.register_plugin
class BoxPlugin(admin.BoxAdminMixin, CMSPluginBase):
    model = models.BoxSettings
    module = _("box")
    name = _("box")
    render_template = "cms/empty.html"
    allow_children = True
    child_classes = settings.CMS_BOX_BOX_CHILD_CLASSES

    def render(self, context, instance, placeholder):
        if instance.status == 0:
            return context

        self.render_template = instance.template_name

        context.update({
            'instance': instance,
            'placeholder': placeholder,
        })
        return context


@plugin_pool.register_plugin
class ModelBoxPlugin(admin.ModelBoxAdminMixin, CMSPluginBase):
    model = models.ModelBoxSettings
    module = _("box")
    name = _("model box")
    render_template = "cms/empty.html"

    def render(self, context, instance, placeholder):
        if instance.status == 0:
            return context

        self.render_template = instance.template_name
        objects = instance.get_objects()

        context.update({
            'instance': instance,
            'placeholder': placeholder,
            'objects': objects,
        })
        return context


class LabelTagAdmin(django_admin.TabularInline):
    model = models.LabelTagSettings
    extra = 0
    fields = ('label', 'tag',)
    fk_name = 'plugin'


@plugin_pool.register_plugin
class FilterBoxPlugin(admin.FilterBoxAdminMixin, CMSPluginBase):
    model = models.FilterBoxSettings
    module = _("box")
    name = _("filter box")
    render_template = "cms/empty.html"
    admin_preview = False
    inlines = (LabelTagAdmin,)

    def render(self, context, instance, placeholder):
        if instance.status == 0:
            return context

        self.render_template = instance.template_name

        context.update({
            'instance': instance,
            'placeholder': placeholder,
        })
        return context
